| Home | Libraries | People | FAQ | More

# Math Toolkit 4.2.0

### Nikhar Agrawal

### Anton Bikineev

### Matthew Borland

### Paul A. Bristow

### Hubert Holin

### Marco Guazzone

### Christopher Kormanyos

### Bruno Lalande

### John Maddock

### Evan Miller

### Jeremy W. Murphy

### Matthew Pulver

### Johan Råde

### Benjamin Sobotta

### Gautam Sewani

### Nicholas Thompson

### Thijs van den Berg

### Daryle Walker

### Xiaogang Zhang

This manual is also available in printer friendly PDF format, and as a CD ISBN 0-9504833-2-X 978-0-9504833-2-0, Classification 519.2-dc22.

Copyright © 2006-2021 Nikhar Agrawal, Anton Bikineev, Matthew Borland, Paul A. Bristow, Marco Guazzone, Christopher Kormanyos, Hubert Holin, Bruno Lalande, John Maddock, Evan Miller, Jeremy Murphy, Matthew Pulver, Johan Råde, Gautam Sewani, Benjamin Sobotta, Nicholas Thompson, Thijs van den Berg, Daryle Walker and Xiaogang Zhang

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)